@@ -25,10 +25,10 @@ int main(int argc, char* argv[])
 
     KAboutData aboutData(QStringLiteral("Baloo"),
                          i18n("Baloo Search"),
-                         PROJECT_VERSION,
+                         QStringLiteral(PROJECT_VERSION),
                          i18n("A tool to search through the files indexed by Baloo"),
                          KAboutLicense::GPL);
-    aboutData.addAuthor(i18n("Vishesh Handa"), i18n("Maintainer"), QStringLiteral("vhanda@kde.org"));
+    aboutData.addAuthor(i18n("Vishesh Handa"), QString(), QStringLiteral("vhanda@kde.org"));
 
     KAboutData::setApplicationData(aboutData);
 
@@ -47,6 +47,8 @@ int main(int argc, char* argv[])
                                         i18n("directory")));
     parser.addOption(QCommandLineOption({QStringLiteral("i"), QStringLiteral("id")},
                                         i18n("Show document IDs")));
+    parser.addOption(QCommandLineOption({QStringLiteral("s"), QStringLiteral("sort")},
+                                        i18n("Sorting criteria"), QStringLiteral("auto|time|none"), QStringLiteral("auto")));
     parser.addPositionalArgument(i18n("query"), i18n("List of words to query for"));
     parser.addHelpOption();
     parser.addVersionOption();
@@ -62,12 +64,27 @@ int main(int argc, char* argv[])
         parser.showHelp(1);
     }
 
-    if (parser.isSet(QStringLiteral("type")))
+    if (parser.isSet(QStringLiteral("type"))) {
         typeStr = parser.value(QStringLiteral("type"));
-    if (parser.isSet(QStringLiteral("limit")))
+    }
+    if (parser.isSet(QStringLiteral("limit"))) {
         queryLimit = parser.value(QStringLiteral("limit")).toInt();
-    if (parser.isSet(QStringLiteral("offset")))
+    }
+    if (parser.isSet(QStringLiteral("offset"))) {
         offset = parser.value(QStringLiteral("offset")).toInt();
+    }
+    const Baloo::Query::SortingOption orderBy = [&parser]() {
+       auto val = parser.value(QStringLiteral("sort"));
+       if (val == QStringLiteral("auto")) {
+           return Baloo::Query::SortAuto;
+       } else if (val == QStringLiteral("time")) {
+           return Baloo::Query::SortAuto;
+       } else if (val == QStringLiteral("none")) {
+           return Baloo::Query::SortNone;
+       } else {
+           parser.showHelp(1);
+       }
+    }();
 
     QString queryStr = args.join(QLatin1Char(' '));
 
@@ -76,6 +93,7 @@ int main(int argc, char* argv[])
     query.setSearchString(queryStr);
     query.setLimit(queryLimit);
     query.setOffset(offset);
+    query.setSortingOption(orderBy);
 
     if (parser.isSet(QStringLiteral("directory"))) {
         QString folderName = parser.value(QStringLiteral("directory"));
@@ -84,7 +102,14 @@ int main(int argc, char* argv[])
             std::cerr << qPrintable(i18n("%1 is not a valid directory", folderName)) << std::endl;
             return 1;
         }
-        query.setIncludeFolder(fi.canonicalFilePath());
+        while (folderName.endsWith(QLatin1Char('/')) && (folderName.size() > 1)) {
+            folderName.chop(1);
+        }
+        auto canonicalPath = fi.canonicalFilePath();
+        if (canonicalPath != folderName) {
+            std::cerr << qPrintable(i18n("Using canonical path '%1' for '%2'", canonicalPath, folderName)) << std::endl;
+        }
+        query.setIncludeFolder(canonicalPath);
     }
 
     QElapsedTimer timer;
@@ -94,7 +119,7 @@ int main(int argc, char* argv[])
     while (iter.next()) {
         const QString filePath = iter.filePath();
         if (showDocumentId) {
-            std::cout << qPrintable(iter.documentId()) << " ";
+            std::cout << iter.documentId().constData() << " ";
         }
         std::cout << qPrintable(filePath) << std::endl;
     }
